@@ -37,7 +37,7 @@ CAPABILITY_IAM = 'CAPABILITY_IAM'
 CAPABILITY_NAMED_IAM = 'CAPABILITY_NAMED_IAM'
 CAPABILITY_AUTO_EXPAND = 'CAPABILITY_AUTO_EXPAND'
 
-cfn = boto3.client('cloudformation')
+_cfn = boto3.client('cloudformation')
 po = PrettyObject()
 
 _deletion_stack = []
@@ -85,6 +85,7 @@ def list_stacks(stack_status_filter=None):
     :param stack_status_filter: The list of stack status types to include (if not present, all types are included)
     :return: a list of all stack summaries or None if the filter was bad
     """
+    global _cfn
     if stack_status_filter is str:
         stack_status_filter = [stack_status_filter]  # handles single filter as string
     stacks_remain = True
@@ -93,13 +94,13 @@ def list_stacks(stack_status_filter=None):
     try:
         while stacks_remain:
             if token and stack_status_filter:
-                stacks = cfn.list_stacks(StackStatusFilter=stack_status_filter, NextToken=token)
+                stacks = _cfn.list_stacks(StackStatusFilter=stack_status_filter, NextToken=token)
             elif stack_status_filter:
-                stacks = cfn.list_stacks(StackStatusFilter=stack_status_filter)
+                stacks = _cfn.list_stacks(StackStatusFilter=stack_status_filter)
             elif token:
-                stacks = cfn.list_stacks(NextToken=token)
+                stacks = _cfn.list_stacks(NextToken=token)
             else:
-                stacks = cfn.list_stacks()
+                stacks = _cfn.list_stacks()
             all_stacks.extend(stacks['StackSummaries'])
             if 'NextToken' in stacks:
                 token = stacks['NextToken']
@@ -116,19 +117,20 @@ def describe_stacks(stack_name=None):
     :param stack_name: The name or ID of the stack you'd like to describe. Must be an ID for deleted stacks
     :return: a list of all stack summaries (or, if a stack_name was specified and not found, None)
     """
+    global _cfn
     stacks_remain = True
     all_stacks = []
     token = None
     try:
         while stacks_remain:
             if token and stack_name:
-                stacks = cfn.describe_stacks(StackName=stack_name, NextToken=token)
+                stacks = _cfn.describe_stacks(StackName=stack_name, NextToken=token)
             elif stack_name:
-                stacks = cfn.describe_stacks(StackName=stack_name)
+                stacks = _cfn.describe_stacks(StackName=stack_name)
             elif token:
-                stacks = cfn.describe_stacks(NextToken=token)
+                stacks = _cfn.describe_stacks(NextToken=token)
             else:
-                stacks = cfn.describe_stacks()
+                stacks = _cfn.describe_stacks()
             all_stacks.extend(stacks['Stacks'])
             if 'NextToken' in stacks:
                 token = stacks['NextToken']
@@ -204,7 +206,7 @@ def wait_for_stack(stack_name: str, pend_status: str):
     return status
 
 
-def create_stack(fn: str, params={}, capabilities=[], stack_name: str = None, debug = False):
+def create_stack(fn: str, params={}, capabilities=[], stack_name: str = None, debug = False, region: str = None):
     """
     Creates a cloud formation stack.  The template file is preprocesssed with Jinja using
     the passed in parameters.
@@ -215,10 +217,13 @@ def create_stack(fn: str, params={}, capabilities=[], stack_name: str = None, de
     something that is powerful such as creating roles.
     :param stack_name: Used to specify a non-standard stack name
     :param debug: If set to True, outputs the template after Jinja template rendering.  Default is False.
+    :param region: If provided, create the template in that region. Otherwise uses the default region.
     :return: `cloudformation.Stack <https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudformation.html#stack>`_
     """
+    global _cfn
     file = None
-
+    if region:
+        _cfn = boto3.client('cloudformation', region_name = region)
     try:
         # create stack name
         (path, filename) = os.path.split(fn)
@@ -241,8 +246,9 @@ def create_stack(fn: str, params={}, capabilities=[], stack_name: str = None, de
         if debug:
             print(template_body)
 
+
         # get params list
-        template_validated = cfn.validate_template(TemplateBody=template_body)
+        template_validated = _cfn.validate_template(TemplateBody=template_body)
 
         # create parameters
         if template_validated.get('Parameters') is not None:
@@ -252,7 +258,7 @@ def create_stack(fn: str, params={}, capabilities=[], stack_name: str = None, de
             ]
 
         # create stack
-        metadata = cfn.create_stack(StackName=stack_name,
+        metadata = _cfn.create_stack(StackName=stack_name,
                                    TemplateBody=template_body,
                                    Parameters=cfn_params,
                                    Capabilities=capabilities,
@@ -267,6 +273,8 @@ def create_stack(fn: str, params={}, capabilities=[], stack_name: str = None, de
             raise Exception(f'Stack creation failed: {stack_name}')
 
         add_to_deletion_stack(stack_name)
+        if region:
+            _cfn = boto3.client('cloudformation')
         return summary
 
     except IOError as e:
@@ -302,8 +310,9 @@ def delete_stack(stack_name: str):
     :param stack_name: Name of stack to remove
     :return: Last known status.
     """
+    global _cfn
     print(f'Deleting {stack_name}...')
-    cfn.delete_stack(StackName=stack_name)
+    _cfn.delete_stack(StackName=stack_name)
     status = wait_for_stack(stack_name, DELETE_IN_PROGRESS)
 
     return status
