@@ -1,5 +1,5 @@
 import boto3
-from aws.region import get_ec2, get_ssm
+from aws.region import get_ec2, get_ssm, get_route53
 import time
 
 def list_regions():
@@ -1494,4 +1494,29 @@ def ssm_run_shell_script(name: str = None, instance_id: str = None, commands = [
           'workingDirectory': [directory]
         }
     )
-    return response
\ No newline at end of file
+    return response
+
+###########################################################################
+# Route53
+###########################################################################
+def list_hosted_zones():
+    """
+    Returns a list of hosted zones. Useful data the list contains are hosted zone IDs and their (domain) names.
+    Note that hosted zones are not region-bound.
+    
+    :return: a list of hosted zones as dicts with the following format: https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53.html#Route53.Client.list_hosted_zones
+    """
+    return get_route53().list_hosted_zones().get('HostedZones', [])
+
+def get_zone_vpc_ids(zone_id: str):
+    """
+    Returns a list of VPC ids associated with a given hosted zone
+
+    :param id: The id of the hosted zone
+    :return: a list of VPC id strings associated with that hosted zone
+    """
+    vpcs = get_route53().get_hosted_zone(Id = zone_id).get('VPCs')
+    return [
+      vpc.get('VPCId')
+      for vpc in vpcs
+    ]
\ No newline at end of file
